from langchain.tools import StructuredTool


def {{ tool_name }}_impl(**kwargs):
    """Describe what this tool does."""
    # TODO: implement
    return {"ok": True, "input": kwargs}


{{ tool_name }} = StructuredTool.from_function(
    name="{{ tool_name }}",
    description="{{ description or 'A custom tool' }}",
    func={{ tool_name }}_impl,
)
