"""
CLI commands for EvenAge.

Provides all CLI commands for project management.
"""

from .add import add
from .check import check
from .infra import infra
from .init import init
from .management import logs, ps, scale, stop
from .prompt import prompt
from .run import run, run_dev_alias


__all__ = [
    "add",
    "check",
    "infra",
    "init",
    "logs",
    "prompt",
    "ps",
    "run",
    "run_dev_alias",
    "scale",
    "stop",
]
