from evenage.core.agent import Agent


class {{ agent_name|capitalize }}Agent(Agent):
    def __init__(self):
        super().__init__(
            name="{{ agent_name }}",
            description="{{ description or 'LangChain-powered agent' }}",
            tools=[],
            allow_delegation={{ allow_delegation|default(True)|lower }},
        )
